# -*- coding: utf-8 -*-
"""
MPD_sima is a non interactive MPD autoqueue client running in the background.
It will queue new tracks chosen among artists similar to your current queued
tracks, provided a title is found in your music library.
Similar artists are fetched from last.fm webservice.

MPD_sima can queue track, top track or whole album for similar artists.

This client allows you to never run out of music when your queue is getting
short.
"""


__version__ = '0.16.1'
__author__ = 'kaliko'
__email__ = 'kaliko@azylum.org'
__url__ = 'git://git.kaliko.me/sima.git'


# VIM MODLINE
# vim: ai ts=4 sw=4 sts=4 expandtab
